function [pnt, der] = surf_der(nurbs,tt)
%FUNCTION:
% Evaluate surface point and Calculate its first derivatives along u and v
% directions on B-spline/NURBS surface
%++++++++++++++++++++++++++++++++++++++++
% INPUT:
% OUTPUT:
% pnt ==> cartesian coordinates of evaluated point, 3X1 vector;
% du ==> 1st order derivative along u direction,  3X1 vector;
% dv ==> 1st order derivative along v direction,  3X1 vector;
%++++++++++++++++++++++++++++++++++++++++

%%%%%%%%%%%%%%%%%%%%%%%%%%%%
u = tt{1};
v = tt{2};

p =  nurbs.order(1);
q =  nurbs.order(2);

tu = nurbs.knots{1};
tv = nurbs.knots{2};

cpc = permute(nurbs.coefs, [2 3 1]);

if size(cpc,3) == 4,
   w = squeeze(cpc(:,:,4));
else
   w = ones(size(cpc,1), size(cpc,2));
end

cpc = cpc(:,:,1:3);

m = size(cpc, 1)-1;
n = size(cpc, 2)-1;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

cptemp=cpc;
cph=cat(3,cptemp,w);
for j=1:(m+p)
    if tu(j)<=u&&u<tu(j+1)
        lu=j;break;
    end
    if u==1
        lu=m+1; break;
    end
end
   
for j=1:(n+q)
    if tv(j)<=v&&v<tv(j+1)
        lv=j;break;
    end
    if v==1
        lv=n+1; break;
    end
end

CPU=reshape(coxdeboor(permute(cph(:,:,:),[2 3 1]),tv,q,lv,v),4,m+1);
CPV=reshape(coxdeboor(permute(cph(:,:,:),[1 3 2]),tu,p,lu,u),4,n+1);

pnth=coxdeboor(CPU',tu,p,lu,u);%=coxdeboor(CPV',tv,q,lv,v) too
temp=pnth/pnth(4);
pnt=temp(1,1:3)';

CPUc=CPU(1:3,:)./repmat(CPU(4,:),3,1);
CPVc=CPV(1:3,:)./repmat(CPV(4,:),3,1);

[pnt,du]=dnurbscrv(CPUc,m,p,tu,CPU(4,:),u);
[pnt,dv]=dnurbscrv(CPVc,n,q,tv,CPV(4,:),v);

der = {du,dv};